#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: securemem
version: 0.1.9
id: securemem-0.1.9-01ec912d1ae68740f3ee3b7079e4f920
key: secur_6yuKG3yG4sMKx00Z54FnpQ
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-securemem
synopsis: abstraction to an auto scrubbing and const time eq, memory chunk.
description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.SecureMem
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/securemem-0.1.9
library-dirs: /usr/lib/ghc-7.10.3/site-local/securemem-0.1.9
data-dir: /usr/share/arm-linux-ghc-7.10.3/securemem-0.1.9
hs-libraries: HSsecuremem-0.1.9-6yuKG3yG4sMKx00Z54FnpQ
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    memory-0.12-092368f288b8a5ed89de3a4f849c43f2
haddock-interfaces: /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html: /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
